"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const office_1 = __importDefault(require("../office"));
jest.setTimeout(30000);
describe('Convert', () => {
    it('Converts a PDF to JPG', () => __awaiter(void 0, void 0, void 0, function* () {
        const randomString = Math.floor(Math.random() * 10000).toString();
        const dir = path_1.default.join(__dirname, '..', '..', 'test');
        const source = path_1.default.join(dir, 'test.pdf');
        const input = path_1.default.join(dir, `test-${randomString}.pdf`);
        const output = path_1.default.join(dir, `test-${randomString}.jpg`);
        fs_1.default.copyFileSync(source, input);
        const options = {
            input,
            outdir: dir,
            type: 'jpg',
        };
        yield (0, office_1.default)(options);
        const fileStats = fs_1.default.statSync(output);
        expect(fileStats.size).toBeGreaterThan(0);
        yield Promise.all([
            new Promise((resolve) => { fs_1.default.unlink(input, () => resolve(true)); }),
            new Promise((resolve) => { fs_1.default.unlink(output, () => resolve(true)); }),
        ]);
    }));
    it('Converts a DOC to PDF', () => __awaiter(void 0, void 0, void 0, function* () {
        const randomString = Math.floor(Math.random() * 10000).toString();
        const dir = path_1.default.join(__dirname, '..', '..', 'test');
        const source = path_1.default.join(dir, 'test.doc');
        const input = path_1.default.join(dir, `test-${randomString}.doc`);
        const output = path_1.default.join(dir, `test-${randomString}.pdf`);
        fs_1.default.copyFileSync(source, input);
        const options = {
            input,
            outdir: dir,
            type: 'pdf',
        };
        yield (0, office_1.default)(options);
        const fileStats = fs_1.default.statSync(output);
        expect(fileStats.size).toBeGreaterThan(0);
        yield Promise.all([
            new Promise((resolve) => { fs_1.default.unlink(input, () => resolve(true)); }),
            new Promise((resolve) => { fs_1.default.unlink(output, () => resolve(true)); }),
        ]);
    }));
    it('Converts a PDF to JPG with callback', (done) => {
        const randomString = Math.floor(Math.random() * 10000).toString();
        const dir = path_1.default.join(__dirname, '..', '..', 'test');
        const source = path_1.default.join(dir, 'test.pdf');
        const input = path_1.default.join(dir, `test-${randomString}.pdf`);
        const output = path_1.default.join(dir, `test-${randomString}.jpg`);
        fs_1.default.copyFileSync(source, input);
        const callback = () => {
            const fileStats = fs_1.default.statSync(output);
            expect(fileStats.size).toBeGreaterThan(0);
            fs_1.default.unlinkSync(input);
            fs_1.default.unlinkSync(output);
            done();
        };
        const options = {
            callback,
            input,
            outdir: dir,
            type: 'jpg',
        };
        (0, office_1.default)(options);
    });
    it('Converts a PDF to buffer', () => __awaiter(void 0, void 0, void 0, function* () {
        const randomString = Math.floor(Math.random() * 10000).toString();
        const dir = path_1.default.join(__dirname, '..', '..', 'test');
        const source = path_1.default.join(dir, 'test.pdf');
        const input = path_1.default.join(dir, `test-${randomString}.pdf`);
        const output = path_1.default.join(dir, `test-${randomString}.jpg`);
        fs_1.default.copyFileSync(source, input);
        const options = {
            input,
            type: 'jpg',
            debug: true,
        };
        const buffer = yield (0, office_1.default)(options);
        expect(buffer.length).toBeGreaterThan(0);
        expect(Buffer.isBuffer(buffer)).toBeTruthy();
        const outputFileExists = yield new Promise((resolve) => { fs_1.default.exists(output, (result) => resolve(result)); });
        expect(outputFileExists).toBeFalsy();
        yield Promise.all([
            new Promise((resolve) => { fs_1.default.unlink(input, () => resolve(true)); }),
        ]);
    }));
});
