"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const child_process_1 = require("child_process");
const debug = (0, debug_1.default)('node-unoconv:command');
const officeConvert = (options) => {
    const { input = '' } = options;
    const inputPath = input.substring(0, input.lastIndexOf('/'));
    const stdout = [];
    const stderr = [];
    const returnToBuffer = !options.outdir;
    const { callback = (() => null), type = 'pdf', outdir = inputPath, } = options;
    if (options.debug) {
        debug_1.default.enable('node-office:*');
    }
    const args = [
        '--convert-to', type,
        input,
        '--accept=socket,host=127.0.0.1,port=2001,tcpNoDelay=1;urp;StarOffice.ComponentContext',
        '--headless',
    ];
    if (outdir) {
        args.push('--outdir', outdir);
    }
    if (returnToBuffer) {
        args.push('-p');
    }
    debug(`Running command: soffice ${args.join(' ')}`);
    const childProcess = (0, child_process_1.spawn)('soffice', args);
    childProcess.stdout.on('data', (data) => {
        stdout.push(data);
    });
    childProcess.stderr.on('data', (data) => {
        stderr.push(data);
    });
    childProcess.on('close', (code) => __awaiter(void 0, void 0, void 0, function* () {
        debug('node-office finished with code: %s', code);
        if (returnToBuffer) {
            const output = input.replace(path_1.default.extname(input), `.${type}`);
            yield new Promise((resolve) => { fs_1.default.unlink(output, () => resolve(true)); });
        }
        if (stderr.length) {
            const error = new Error(Buffer.concat(stderr).toString('utf8'));
            debug('%o', error);
            callback(error);
            return;
        }
        callback(null, Buffer.concat(stdout));
    }));
    childProcess.on('error', (err) => {
        if (err.message.indexOf('ENOENT') > -1) {
            debug('soffice command not found. %o', err);
            return;
        }
        debug('%o', err);
    });
    return childProcess;
};
const convert = (options) => {
    if (!options.callback) {
        // Return a promise if there is no callback
        return new Promise((resolve, reject) => {
            // Assign a fake callback that would either resolve or reject the promise
            const callback = (err, result) => (err
                ? reject(err)
                : resolve(result));
            const runOptions = Object.assign(Object.assign({}, options), { callback });
            officeConvert(runOptions);
        });
    }
    return officeConvert(options);
};
exports.default = convert;
